#!/bin/bash

# 检测可用工具（curl优先）
if command -v curl &> /dev/null; then
  SEND_REQUEST="curl -X POST -H \"Content-Type: application/json\" -d"
elif command -v wget &> /dev/null; then
  SEND_REQUEST="wget -qO- --header=\"Content-Type: application/json\" --post-data"
else
  echo "Error: Neither curl nor wget is installed."
  exit 1
fi

# 无限循环，每5秒执行一次
while true; do
  # 获取URL
  SERVER_IP=$(grep -oP 'server_ip\s*=\s*\K[^\s]+' "$HOME/.chx/config.ini" | cut -d':' -f1)
  URL="http://$SERVER_IP:18880/client/updateHostInfo"

  # 获取开机小时数（保留1位小数）
  STARTUP_SECONDS=$(cat /proc/uptime | awk '{print $1}')
  STARTUP_HOURS=$(echo $(printf "%.1f" `echo "scale=1; $STARTUP_SECONDS/3600+0.1" | bc`))

  # 获取CPU使用率（1秒内的平均值，保留1位小数）
  CPU_USAGE=$(top -bn1 | grep "Cpu(s)" | sed "s/.*, *\([0-9.]*\)%* id.*/\1/" | awk '{print 100 - $1}' | awk '{printf "%.1f", $1}')

  # 获取内存使用率（保留1位小数）
  MEMORY_USAGE=$(LANG=C free | grep Mem | awk '{printf "%.1f", $3/$2 * 100}')

  # 获取磁盘根分区使用率（保留1位小数）
  DISK_USAGE=$(df -h / | grep / | awk '{print $5}' | sed 's/%//g' | awk '{printf "%.1f", $1}')

  # 手动构造JSON数据
  JSON_DATA="{\"startup_hours\": $STARTUP_HOURS, \"cpu\": $CPU_USAGE, \"mem\": $MEMORY_USAGE, \"disk\": $DISK_USAGE}"

  # 发送请求
  echo "SEND $URL $JSON_DATA"
  eval "$SEND_REQUEST '$JSON_DATA' $URL" &> /dev/null

  # 等待5秒
  sleep 5
done
